@@ -1,12 +1,16 @@
 package Net::DNS::Header;
+#
+# $Id: Header.pm,v 1.13 2003/09/19 18:28:24 ctriv Exp $
+#
 
 use strict;
 use vars qw($VERSION $AUTOLOAD);
 
 use Net::DNS;
 
-# $Id: Header.pm,v 1.8 2002/10/12 19:38:30 ctriv Exp $
-$VERSION = $Net::DNS::VERSION;
+use constant MAX_ID => 65535;
+
+$VERSION = (qw$Revision: 1.13 $)[1];
 
 =head1 NAME
 
@@ -39,6 +43,14 @@ the data is incomplete).
 
 =cut
 
+{
+	my $id = int rand(MAX_ID);
+	
+	sub nextid {
+		return $id++ % (MAX_ID + 1);
+	}
+}
+
 sub new {
 	my $class = shift;
 	my %self;
@@ -70,7 +82,7 @@ sub new {
 	}
 	else { 
 		%self = (
-			"id"		=> Net::DNS::Resolver::nextid(),
+			"id"		=> nextid(),
 			"qr"		=> 0,
 			"opcode"	=> 0,
 			"aa"		=> 0,
@@ -206,6 +218,8 @@ Gets or sets the recursion desired flag.
 
 Gets or sets the checking disabled flag.
 
+
+
 =head2 ra
 
     print "recursion is ", $header->ra ? "" : "not ", "available\n";
@@ -213,6 +227,19 @@ Gets or sets the checking disabled flag.
 
 Gets or sets the recursion available flag.
 
+
+=head2 ad
+
+    print "The result has ", $header->ad ? "" : "not", "been verified\n"
+
+
+Relevant in DNSSEC context.
+
+(The AD bit is only set on answers where signatures have been
+cryptographically verified or the server is authoritative for the data
+and is allowed to set the bit by policy.)
+
+
 =head2 rcode
 
     print "query response code = ", $header->rcode, "\n";
@@ -309,7 +336,8 @@ sub data {
 	          | $self->{"rd"};
 
 	my $byte3 = ($self->{"ra"} << 7)
-                  | ($self->{"cd"} << 4)
+	          | ($self->{"ad"} << 5)
+	          | ($self->{"cd"} << 4)
 	          | $rcode;
 
 	return pack("n C2 n4", $self->{"id"},
@@ -323,9 +351,12 @@ sub data {
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2000 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
+
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
