@@ -1,6 +1,6 @@
 package Net::DNS::RR;
 #
-# $Id: RR.pm,v 1.30 2003/08/28 15:11:54 ctriv Exp $
+# $Id: RR.pm,v 1.32 2003/10/27 14:44:42 ctriv Exp $
 #
 use strict;
 use vars qw($VERSION $AUTOLOAD);
@@ -8,7 +8,7 @@ use vars qw($VERSION $AUTOLOAD);
 use Carp;
 use Net::DNS;
 
-$VERSION = (qw$Revision: 1.30 $)[1];
+$VERSION = (qw$Revision: 1.32 $)[1];
 
 =head1 NAME
 
@@ -165,7 +165,7 @@ sub build_regex {
 Returns a C<Net::DNS::RR> object of the appropriate type and
 initialized from the string passed by the user.  The format of the
 string is that used in zone files, and is compatible with the string
-returned by C<<Net::DNS::RR->string>>.
+returned by C<< Net::DNS::RR->string >>.
 
 The name and RR type are required; all other information is optional.
 If omitted, the TTL defaults to 0 and the RR class defaults to IN.
@@ -698,9 +698,12 @@ RR objects.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2002 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
+
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 
 EDNS0 extensions by Olaf Kolkman.
 
