@@ -1,18 +1,21 @@
 package Net::DNS::Resolver;
 #
-# $Id: Resolver.pm,v 1.39 2003/09/03 04:41:50 ctriv Exp $
+# $Id: Resolver.pm,v 1.43 2003/12/01 04:33:50 ctriv Exp $
 #
 
 use strict;
 use vars qw($VERSION @ISA);
 
-$VERSION = (qw$Revision: 1.39 $)[1];
+$VERSION = (qw$Revision: 1.43 $)[1];
 
 BEGIN {
 	if ($^O eq 'MSWin32') {
 		require Net::DNS::Resolver::Win32;
 		@ISA = qw(Net::DNS::Resolver::Win32);
-	} else {
+	} elsif ($^O eq 'cygwin') {
+		 require Net::DNS::Resolver::Cygwin;
+		 @ISA = qw(Net::DNS::Resolver::Cygwin);
+	} else {   
 		require Net::DNS::Resolver::UNIX;
 		@ISA = qw(Net::DNS::Resolver::UNIX);
 	}
@@ -162,6 +165,8 @@ An array reference of domains.
 
 =item persistent_tcp
 
+=item persistent_udp
+
 =item dnssec
 
 =back
@@ -292,7 +297,7 @@ A and IN.  If the name looks like an IP address (4 dot-separated numbers),
 then an appropriate PTR query will be performed.
 
 Returns a C<Net::DNS::Packet> object whether there were any answers or not.
-Use C<<$packet->header->ancount>> or C<<$packet->answer>> to find out
+Use C<< $packet->header->ancount >> or C<< $packet->answer >> to find out
 if there were any records in the answer section.  Returns C<undef> if there
 was an error.
 
@@ -304,7 +309,7 @@ was an error.
     $socket = $res->bgsend('user.passwd.example.com', 'TXT', 'HS');
 
 Performs a background DNS query for the given name, i.e., sends a
-query packet to the first nameserver listed in C<<$res->nameservers>>
+query packet to the first nameserver listed in C<< $res->nameservers >>
 and returns immediately without waiting for a response.  The program
 can then perform other tasks while waiting for a response from the 
 nameserver.
@@ -315,8 +320,8 @@ A and IN.  If the name looks like an IP address (4 dot-separated numbers),
 then an appropriate PTR query will be performed.
 
 Returns an C<IO::Socket::INET> object.  The program must determine when
-the socket is ready for reading and call C<<$res->bgread>> to get
-the response packet.  You can use C<<$res->bgisready>> or C<IO::Select>
+the socket is ready for reading and call C<< $res->bgread >> to get
+the response packet.  You can use C<< $res->bgisready >> or C<IO::Select>
 to find out if the socket is ready before reading it.
 
 =head2 bgread
@@ -341,7 +346,7 @@ The programmer should close or destroy the socket object after reading it.
     $socket = undef;
 
 Determines whether a socket is ready for reading.  The argument is
-an C<IO::Socket> object returned by C<<$res->bgsend>>.
+an C<IO::Socket> object returned by C<< $res->bgsend >>.
 
 Returns true if the socket is ready, false if not.
 
@@ -519,6 +524,16 @@ or updates to the same nameserver.
 This option defaults to false unless you're running under a
 SOCKSified Perl, in which case it defaults to true.
 
+=head2 persistent_udp
+
+    print 'Persistent UDP flag: ', $res->persistent_udp, "\n";
+    $res->persistent_udp(1);
+
+Get or set the persistent UDP setting.  If set to true, Net::DNS
+will keep a single UDP socket open for all queries.
+This is useful if you're using UDP and need to make a lot of queries
+or updates.
+
 =head2 igntc
 
     print 'igntc flag: ', $res->igntc, "\n";
@@ -582,6 +597,26 @@ recovery.
 
 Default udppacketsize is &Net::DNS::PACKETSZ (512)
 
+=head1 CUSTOMIZING
+
+Net::DNS::Resolver is actually an empty subclass.  At compile time a
+super class is chosen based on the current platform.  A side benefit of
+this allows for easy modification of the methods in Net::DNS::Resolver. 
+You simply add a method to the namespace!  
+
+For example, if we wanted to cache lookups:
+
+ package Net::DNS::Resolver;
+ 
+ my %cache;
+ 
+ sub search {
+	my ($self, @args) = @_;
+	
+	return $cache{@args} ||= $self->SUPER::search(@args);
+ } 
+
+
 =head1 ENVIRONMENT
 
 The following environment variables can also be used to configure
